<?php
/**
 * Theme Functions and Setup
 *
 * @package Urna
 */

if (!function_exists('urna_tbay_private_size_image_setup')) {
    /**
     * Set up custom image sizes
     */
    function urna_tbay_private_size_image_setup() {
        $thumbnail_size = apply_filters('urna_thumbnail_size', [
            'width'  => 640,
            'height' => 400,
            'crop'   => true
        ]);
        set_post_thumbnail_size($thumbnail_size['width'], $thumbnail_size['height'], $thumbnail_size['crop']);

        if (!urna_tbay_get_global_config('config_media', false)) {
            $image_sizes = apply_filters('urna_image_sizes', [
                'thumbnail' => ['width' => $thumbnail_size['width'], 'height' => $thumbnail_size['height']],
                'medium'    => ['width' => 570, 'height' => 330],
                'large'     => ['width' => 770, 'height' => 440],
            ]);

            foreach ($image_sizes as $size => $dimensions) {
                update_option("{$size}_size_w", absint($dimensions['width']));
                update_option("{$size}_size_h", absint($dimensions['height']));
            }
        }
    }
    add_action('after_setup_theme', 'urna_tbay_private_size_image_setup');
}

if (!function_exists('urna_tbay_private_menu_setup')) {
    /**
     * Register navigation menus
     */
    function urna_tbay_private_menu_setup() {
        $menus = apply_filters('urna_nav_menus', [
            'primary'           => esc_html__('Primary Menu', 'urna'),
            'mobile-menu'       => esc_html__('Mobile Menu', 'urna'),
            'nav-category-menu' => esc_html__('Nav Category Menu', 'urna'),
            'track-order'       => esc_html__('Tracking Order Menu', 'urna'),
        ]);
        register_nav_menus($menus);
    }
    add_action('after_setup_theme', 'urna_tbay_private_menu_setup');
}

if (!function_exists('urna_fonts_url')) {
    /**
     * Generate Google Fonts URL with transient caching
     *
     * @return string Sanitized Google Fonts URL
     */
    function urna_fonts_url() {
        $transient_key = 'urna_fonts_url';
        $fonts_url = get_transient($transient_key);
        
        if (false === $fonts_url) {
            $poppins = _x('on', 'Poppins font: on or off', 'urna');
            
            if ('off' !== $poppins) {
                $font_families = apply_filters('urna_font_families', ['Poppins:400,500,600,700']);
                
                $query_args = [
                    'family'  => rawurlencode(implode('|', $font_families)),
                    'subset'  => urlencode('latin,latin-ext'),
                    'display' => urlencode('swap'),
                ];

                $protocol = is_ssl() ? 'https' : 'http';
                $fonts_url = add_query_arg($query_args, "$protocol://fonts.googleapis.com/css");
                $fonts_url = esc_url_raw($fonts_url);
                
                set_transient($transient_key, $fonts_url, WEEK_IN_SECONDS);
            } else {
                $fonts_url = '';
            }
        }
        
        return $fonts_url;
    }
}

if (!function_exists('urna_tbay_fonts_url')) {
    /**
     * Enqueue theme fonts based on configuration.
     *
     * @since Urna 1.0
     */
    function urna_tbay_fonts_url() {
        $show_typography = urna_tbay_get_config('show_typography', false);
        $font_source = urna_tbay_get_config('font_source', '1');
        $font_google_code = urna_tbay_get_config('font_google_code');

        if (!$show_typography) {
            wp_enqueue_style('urna-theme-fonts', urna_fonts_url(), [], null);
        } elseif ('2' === $font_source && !empty($font_google_code)) {
            wp_enqueue_style('urna-theme-fonts', esc_url_raw($font_google_code), [], null);
        }
    }
    add_action('wp_enqueue_scripts', 'urna_tbay_fonts_url');
}


if (!function_exists('urna_tbay_private_widgets_init')) {
    /**
     * Register widget areas
     */
    function urna_tbay_private_widgets_init() {
        if (defined('URNA_CORE_ACTIVED') && URNA_CORE_ACTIVED) {
            $sidebars = apply_filters('urna_sidebars', [
                [
                    'name'          => esc_html__('Canvas Menu Sidebar', 'urna'),
                    'id'            => 'canvas-menu',
                    'description'   => esc_html__('Add widgets here to appear in canvas menu sidebar.', 'urna'),
                    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
                    'after_widget'  => '</aside>',
                    'before_title'  => '<h2 class="widget-title">',
                    'after_title'   => '</h2>',
                ]
            ]);

            foreach ($sidebars as $sidebar) {
                register_sidebar($sidebar);
            }
        }
    }
    add_action('widgets_init', 'urna_tbay_private_widgets_init');
}

if (!function_exists('urna_tbay_blog_meta_list_start')) {
    /**
     * Blog meta wrapper start
     */
    function urna_tbay_blog_meta_list_start() {
        echo '<div class="group-meta-wrapper">';
    }
    add_action('urna_blog_before_meta_list', 'urna_tbay_blog_meta_list_start', 10);
}

if (!function_exists('urna_tbay_blog_meta_list_end')) {
    /**
     * Blog meta wrapper end
     */
    function urna_tbay_blog_meta_list_end() {
        echo '</div>';
    }
    add_action('urna_blog_after_meta_list', 'urna_tbay_blog_meta_list_end', 10);
}