<?php
if (!defined('ABSPATH') || function_exists('Urna_Elementor_Widget_Base')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Core\Files\File_Types\Svg;

abstract class Urna_Elementor_Widget_Base extends Elementor\Widget_Base
{
    /**
     * Get template name by removing 'tbay-' prefix.
     *
     * @return string Template name.
     */
    public function get_name_template() {
        return str_replace('tbay-', '', $this->get_name());
    }

    /**
     * Define widget categories.
     *
     * @return array Categories.
     */
    public function get_categories() {
        return ['urna-elements'];
    }

    /**
     * Get widget name.
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'urna-base';
    }

    /**
     * Load and render a view template.
     *
     * @param string $tpl_slug Template slug.
     * @param string $tpl_name Template name.
     * @param array  $settings Settings array.
     */
    protected function get_view_template($tpl_slug, $tpl_name, $settings = []) {
        if (empty($settings)) {
            $settings = $this->get_settings_for_display();
        }

        $templates = [];
        if (!empty($tpl_name)) {
            $tpl_name = trim(str_replace('.php', '', $tpl_name), DIRECTORY_SEPARATOR);
            $templates[] = "elementor_templates/{$tpl_slug}-{$tpl_name}.php";
            $templates[] = "elementor_templates/{$tpl_slug}/{$tpl_name}.php";
        }
        $templates[] = "elementor_templates/{$tpl_slug}.php";

        foreach ($templates as $template) {
            if (file_exists(URNA_THEMEROOT . '/' . $template)) {
                include locate_template($template);
                return;
            }
        }

        printf(__('Failed to load template with slug "%s" and name "%s".', 'urna'), esc_html($tpl_slug), esc_html($tpl_name));
    }

    /**
     * Render widget output.
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $this->add_render_attribute('wrapper', 'class', [
            'tbay-element',
            'tbay-addon',
            'tbay-addon-' . $this->get_name_template()
        ]);

        $this->get_view_template($this->get_name_template(), '', $settings);
    }

    /**
     * Register heading controls.
     *
     * @param array $condition Conditions for section visibility.
     */
    protected function register_controls_heading($condition = array())
    {
        $this->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Heading', 'urna'),
                'condition' => $condition,
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' => esc_html__('Alignment', 'urna'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'urna'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'urna'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'urna'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon-title' => 'text-align: {{VALUE}};',
                    '{{WRAPPER}} .description' => 'text-align: {{VALUE}};',
                ],
            ]
        );
     

        $this->add_control(
            'heading_title',
            [
                'label' => esc_html__('Title', 'urna'),
                'type' => Controls_Manager::TEXT,
            ]
        );

        $this->add_control(
            'heading_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'urna'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                    'div' => 'div',
                    'span' => 'span',
                    'p' => 'p',
                ],
                'default' => 'h3',
            ]
        );

        $this->add_control(
            'heading_subtitle',
            [
                'label' => esc_html__('Sub Title', 'urna'),
                'type' => Controls_Manager::TEXT,
            ]
        );


        $this->add_control(
            'heading_description',
            [
                'label' => esc_html__('Description', 'urna'),
                'type' => Controls_Manager::TEXTAREA,
            ]
        );
     
        $this->end_controls_section();

        $this->start_controls_section(
            'section_style_heading',
            [
                'label' => esc_html__('Heading', 'urna'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => $condition,
            ]
        );
        $this->register_title_styles();
        $this->register_sub_title_styles();
        $this->register_description_styles();
        $this->register_content_styles();
        $this->end_controls_section();
    }

    /**
     * Remove heading description control.
     */
    protected function register_remove_heading_element() {
        $this->remove_control('heading_description');
        $this->remove_control('styles'); // Remove undefined control.
    }

    /**
     * Register content styling controls.
     */
    private function register_content_styles()
    {
        $this->add_control(
            'heading_stylecontent',
            [
                'label' => esc_html__('Content', 'urna'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'heading_style_margin',
            [
                'label' => esc_html__('Margin', 'urna'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon .tbay-addon-title,{{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title, #tbay-main-content {{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'heading_style_padding',
            [
                'label' => esc_html__('Padding', 'urna'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon .tbay-addon-title,{{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title, #tbay-main-content {{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'heading_style_bg',
            [
                'label' => esc_html__('Background', 'urna'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon .tbay-addon-title,{{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title, #tbay-main-content {{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title' => 'background: {{VALUE}};',
                ],
            ]
        );
    }

    /**
     * Register title styling controls.
     */
    private function register_title_styles()
    {
        $this->add_control(
            'heading_styletitle',
            [
                'label' => esc_html__('Title', 'urna'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs('heading_title_colors');

        $this->start_controls_tab(
            'heading_title_colors_normal',
            [
                'label' => esc_html__('Normal', 'urna'),
            ]
        );

        $this->add_control(
            'heading_title_color',
            [
                'label' => esc_html__('Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon .tbay-addon-title .title,{{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title, #tbay-main-content {{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title' => 'color: {{VALUE}} !important;',
                ],
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'heading_title_colors_hover',
            [
                'label' => esc_html__('Hover', 'urna'),
            ]
        );

        $this->add_control(
            'heading_title_color_hover',
            [
                'label' => esc_html__('Hover Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon .tbay-addon-title .title:hover,{{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title:hover, #tbay-main-content {{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_title_typography',
                'selector' => '{{WRAPPER}} .tbay-addon .tbay-addon-title .title,{{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title, #tbay-main-content {{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title',
            ]
        );

        $this->add_responsive_control(
            'heading_title_margin',
            [
                'label' => esc_html__('Margin', 'urna'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon .tbay-addon-title .title,{{WRAPPER}} .tbay-addon .tbay-addon-nav-menu .tbay-addon-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
    }

    /**
     * Register subtitle styling controls.
     */
    private function register_sub_title_styles()
    {
        $this->add_control(
            'heading_stylesubtitle',
            [
                'label' => esc_html__('Sub title', 'urna'),
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'heading_subtitle!' => ''
                ],
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs('heading_subtitle_colors');

        $this->start_controls_tab(
            'heading_subtitle_colors_normal',
            [
                'label' => esc_html__('Normal', 'urna'),
                'condition' => [
                    'heading_subtitle!' => ''
                ],
            ]
        );

        $this->add_control(
            'heading_subtitle_color',
            [
                'label' => esc_html__('Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'condition' => [
                    'heading_subtitle!' => ''
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon .tbay-addon-title .subtitle' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'heading_subtitle_colors_hover',
            [
                'label' => esc_html__('Hover', 'urna'),
                'condition' => [
                    'heading_subtitle!' => ''
                ],
            ]
        );

        $this->add_control(
            'heading_subtitle_color_hover',
            [
                'label' => esc_html__('Hover Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'heading_subtitle!' => ''
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon .tbay-addon-title .subtitle:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_subtitle_typography',
                'condition' => [
                    'heading_subtitle!' => ''
                ],
                'selector' => '{{WRAPPER}} .tbay-addon .tbay-addon-title .subtitle',
            ]
        );

        $this->add_responsive_control(
            'heading_subtitle_margin',
            [
                'label' => esc_html__('Margin', 'urna'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon .tbay-addon-title .subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'heading_subtitle!' => ''
                ],
            ]
        );
    }

    /**
     * Register description styling controls.
     */
    private function register_description_styles()
    {
        $this->add_control(
            'heading_style_description',
            [
                'label' => esc_html__('Description', 'urna'),
                'type' => Controls_Manager::HEADING,
                'condition' => [
                    'heading_description!' => ''
                ],
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs('heading_description_colors');

        $this->start_controls_tab(
            'heading_description_colors_normal',
            [
                'label' => esc_html__('Normal', 'urna'),
                'condition' => [
                    'heading_description!' => ''
                ],
            ]
        );

        $this->add_control(
            'heading_description_color',
            [
                'label' => esc_html__('Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'condition' => [
                    'heading_description!' => ''
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon.tbay-addon-text-heading .description' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'heading_description_colors_hover',
            [
                'label' => esc_html__('Hover', 'urna'),
                'condition' => [
                    'heading_description!' => ''
                ],
            ]
        );

        $this->add_control(
            'heading_description_color_hover',
            [
                'label' => esc_html__('Hover Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'heading_description!' => ''
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon.tbay-addon-text-heading .description:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'heading_description_typography',
                'condition' => [
                    'heading_description!' => ''
                ],
                'selector' => '{{WRAPPER}} .tbay-addon.tbay-addon-text-heading .description',
            ]
        );

        $this->add_responsive_control(
            'heading_description_margin',
            [
                'label' => esc_html__('Margin', 'urna'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-addon.tbay-addon-text-heading .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'heading_description!' => ''
                ],
            ]
        );
    }

    /**
     * Get available pages with caching.
     *
     * @return array Page options.
     */
    protected function get_available_pages() {
        $cache_key = 'urna_available_pages';
        if (false === ($pages = get_transient($cache_key))) {
            $pages = wp_list_pluck(get_pages(), 'post_title', 'ID');
            set_transient($cache_key, $pages, HOUR_IN_SECONDS);
        }
        return $pages;
    }

    /**
     * Retrieve available on-sale products for use in options.
     *
     * @return array An array of product IDs and titles.
     */
    protected function get_available_on_sale_products() {
        $transient_key = 'urna_on_sale_products_options';
        $options = get_transient($transient_key);

        if ($options) {
            return $options;
        }

        $product_ids_on_sale = wc_get_product_ids_on_sale();
        if (empty($product_ids_on_sale)) {
            return [];
        }

        $product_ids_on_sale[] = 0;

        $args = [
            'post_type'      => 'product',
            'post_status'    => 'publish',
            'posts_per_page' => apply_filters('urna_on_sale_products_limit', 100),
            'post__in'       => $product_ids_on_sale,
            'no_found_rows'  => true,
        ];

        $query = new WP_Query($args);
        $options = wp_list_pluck($query->posts, 'post_title', 'ID');
        wp_reset_postdata();
        
        set_transient($transient_key, $options, WEEK_IN_SECONDS);

        return $options;
    }

    /**
     * Get available on-sale products with countdown and caching.
     *
     * @return array Product options.
     */
    protected function get_available_products_countdown() {
        $cache_key = 'urna_products_countdown';

        $options = get_transient($cache_key);

        if ($options) {
            return $options;
        }

        $args = [
            'post_type' => 'product',
            'posts_per_page' => -1,
            'post__in' => array_merge(wc_get_product_ids_on_sale(), [0]),
            'meta_query' => [
                [
                    'key' => '_sale_price_dates_to',
                    'value' => '',
                    'compare' => '!=',
                ],
            ],
        ];

        $query = new WP_Query($args);
        $options = wp_list_pluck($query->posts, 'post_title', 'ID');
        wp_reset_postdata();
        set_transient($cache_key, $options, WEEK_IN_SECONDS);

        return $options;
    }

    /**
     * Get available menus with caching and WPML support.
     *
     * @return array Menu options.
     */
    protected function get_available_menus() {
        return urna_wpml_is_activated() ? $this->get_available_menus_wpml() : $this->get_available_menus_default();
    }

    /**
     * Get available menus without WPML with caching.
     *
     * @return array Menu options.
     */
    protected function get_available_menus_default() {
        $cache_key = 'urna_menus_default';
        if (false === ($options = get_transient($cache_key))) {
            $menus = wp_get_nav_menus();
            $options = $menus ? wp_list_pluck($menus, 'name', 'slug') : [];
            set_transient($cache_key, $options, HOUR_IN_SECONDS);
        }
        return $options;
    }

    /**
     * Get available menus with WPML and caching.
     *
     * @return array Menu options.
     */
    protected function get_available_menus_wpml() {
        global $sitepress;
        $cache_key = 'urna_menus_wpml_' . apply_filters('wpml_current_language', null);
        if (false === ($options = get_transient($cache_key))) {
            $menus = wp_get_nav_menus();
            $options = [];
            $current_lang = apply_filters('wpml_current_language', null);

            foreach ($menus as $menu) {
                $menu_details = $sitepress->get_element_language_details($menu->term_taxonomy_id, 'tax_nav_menu');
                if (isset($menu_details->language_code) && $menu_details->language_code === $current_lang) {
                    $options[urna_get_transliterate($menu->slug)] = $menu->name;
                }
            }
            set_transient($cache_key, $options, HOUR_IN_SECONDS);
        }
        return $options;
    }

    /**
     * Render heading element.
     *
     * @param string $class Additional CSS classes.
     */
    public function render_element_heading($class = '') {
        $settings = $this->get_settings_for_display();
        extract($settings);

        if (empty($heading_subtitle) && empty($heading_title) && empty($heading_description)) {
            return;
        }

        if (!empty($heading_subtitle) || !empty($heading_title)) {
            printf(
                '<%1$s class="tbay-addon-title %2$s">%3$s%4$s</%1$s>',
                esc_attr($heading_title_tag),
                esc_attr($class),
                !empty($heading_title) ? '<span class="title">' . trim($heading_title) . '</span>' : '',
                !empty($heading_subtitle) ? '<span class="subtitle">' . trim($heading_subtitle) . '</span>' : ''
            );
        }

        if (!empty($heading_description)) {
            printf('<div class="description">%s</div>', trim($heading_description));
        }
    }

    /**
     * Get product type options.
     *
     * @return array Product types.
     */
    protected function get_product_type() {
        $types = [
            'newest' => esc_html__('Newest Products', 'urna'),
            'on_sale' => esc_html__('On Sale Products', 'urna'),
            'best_selling' => esc_html__('Best Selling', 'urna'),
            'top_rated' => esc_html__('Top Rated', 'urna'),
            'featured' => esc_html__('Featured Product', 'urna'),
            'random_product' => esc_html__('Random Product', 'urna'),
        ];

        return apply_filters('urna_woocommerce_product_type', $types);
    }

    /**
     * Get title for product type.
     *
     * @param string $key Product type key.
     * @return string Title.
     */
    protected function get_title_product_type($key) {
        $types = $this->get_product_type();
        return $types[$key] ?? '';
    }

    /**
     * Get product categories with caching.
     *
     * @param int $number Number of categories to retrieve.
     * @return array Category options.
     */
    protected function get_product_categories($number = '') {
        $cache_key = 'urna_product_categories_' . ($number ?: 'all');
        if (false === ($categories = get_transient($cache_key))) {
            $args = [
                'taxonomy' => 'product_cat',
                'hide_empty' => false,
            ];
            if ($number && $number !== -1) {
                $args['number'] = $number;
            }

            $terms = get_terms($args);
            $categories = is_wp_error($terms) ? [] : array_reduce($terms, function ($result, $term) {
                $result[urna_get_transliterate($term->slug)] = sprintf('%s (%d)', $term->name, $term->count);
                return $result;
            }, []);
            set_transient($cache_key, $categories, HOUR_IN_SECONDS);
        }
        return $categories;
    }

    /**
     * Get category operator options.
     *
     * @return array Operator options.
     */
    protected function get_cat_operator() {
        $operators = [
            'IN' => esc_html__('IN', 'urna'),
            'NOT IN' => esc_html__('NOT IN', 'urna'),
        ];

        return apply_filters('urna_woocommerce_cat_operator', $operators);
    }

    /**
     * Get WooCommerce order by options.
     *
     * @return array Order by options.
     */
    protected function get_woo_order_by() {
        $order_by = [
            'date' => esc_html__('Date', 'urna'),
            'title' => esc_html__('Title', 'urna'),
            'id' => esc_html__('ID', 'urna'),
            'price' => esc_html__('Price', 'urna'),
            'popularity' => esc_html__('Popularity', 'urna'),
            'rating' => esc_html__('Rating', 'urna'),
            'rand' => esc_html__('Random', 'urna'),
            'menu_order' => esc_html__('Menu Order', 'urna'),
        ];

        return apply_filters('urna_woocommerce_oder_by', $order_by);
    }

    /**
     * Get WooCommerce order options.
     *
     * @return array Order options.
     */
    protected function get_woo_order() {
        $order = [
            'asc' => esc_html__('ASC', 'urna'),
            'desc' => esc_html__('DESC', 'urna'),
        ];

        return apply_filters('urna_woocommerce_order', $order);
    }

    /**
     * Register layout type control.
     */
    protected function register_woocommerce_layout_type() {
        $this->add_control(
            'layout_type',
            [
                'label' => esc_html__('Layout Type', 'urna'),
                'type' => Controls_Manager::SELECT,
                'default' => 'grid',
                'options' => [
                    'grid' => 'Grid',
                    'carousel' => 'Carousel',
                    'vertical' => 'Vertical',
                ],
            ]
        );
    }

    /**
     * Register WooCommerce order controls.
     */
    protected function register_woocommerce_order() {
        $this->add_control(
            'orderby',
            [
                'label' => esc_html__('Order By', 'urna'),
                'type' => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => $this->get_woo_order_by(),
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        ['name' => 'product_type', 'operator' => '!==', 'value' => 'top_rated'],
                        ['name' => 'product_type', 'operator' => '!==', 'value' => 'random_product'],
                        ['name' => 'product_type', 'operator' => '!==', 'value' => 'best_selling'],
                    ],
                ],
            ]
        );

        $this->add_control(
            'order',
            [
                'label' => esc_html__('Order', 'urna'),
                'type' => Controls_Manager::SELECT,
                'default' => 'asc',
                'options' => $this->get_woo_order(),
                'conditions' => [
                    'relation' => 'and',
                    'terms' => [
                        ['name' => 'product_type', 'operator' => '!==', 'value' => 'top_rated'],
                        ['name' => 'product_type', 'operator' => '!==', 'value' => 'random_product'],
                        ['name' => 'product_type', 'operator' => '!==', 'value' => 'best_selling'],
                    ],
                ],
            ]
        );
    }

    /**
     * Register WooCommerce categories and operator controls.
     */
    protected function register_woocommerce_categories_operator() {
        $categories = $this->get_product_categories();

        $this->add_control(
            'categories',
            [
                'label' => esc_html__('Categories', 'urna'),
                'type' => Controls_Manager::SELECT2,
                'label_block' => true,
                'default' => !empty($categories) ? array_key_first($categories) : '',
                'options' => $categories,
                'multiple' => true,
            ]
        );

        $this->add_control(
            'cat_operator',
            [
                'label' => esc_html__('Category Operator', 'urna'),
                'type' => Controls_Manager::SELECT,
                'default' => 'IN',
                'options' => $this->get_cat_operator(),
                'condition' => ['categories!' => ''],
            ]
        );
    }

    /**
     * Get WooCommerce product tags with caching.
     *
     * @return array Tag options.
     */
    protected function get_woocommerce_tags() {
        $cache_key = 'urna_product_tags';
        if (false === ($tags = get_transient($cache_key))) {
            $terms = get_terms(['taxonomy' => 'product_tag', 'order' => 'ASC']);
            $tags = is_wp_error($terms) ? [] : array_reduce($terms, function ($result, $tag) {
                $result[$tag->slug] = sprintf('%s (%d)', $tag->name, $tag->count);
                return $result;
            }, []);
            set_transient($cache_key, $tags, HOUR_IN_SECONDS);
        }
        return $tags;
    }

    /**
     * Configure layout settings.
     */
    public function settings_layout() {
        $settings = $this->get_settings_for_display();
        if (!isset($settings['layout_type'])) {
            return;
        }

        $this->add_render_attribute('row', 'class', $this->get_name_template());

        if (!empty($settings['rows'])) {
            $this->add_render_attribute('row', 'class', "rows-{$settings['rows']}");
            if ($settings['rows'] != 1) {
                $this->add_render_attribute('row', 'class', 'row-no-one');
            }
        }

        $settings['layout_type'] === 'carousel' ? $this->settings_carousel($settings) : $this->settings_responsive($settings);
    }

    /**
     * Get image field output.
     *
     * @param array $image Image settings.
     * @return string HTML image tag.
     */
    protected function get_widget_field_img($image) {
        if (!empty($image['id'])) {
            return wp_get_attachment_image($image['id'], 'full');
        }
        if (!empty($image['url'])) {
            return sprintf('<img src="%s" alt="">', esc_url($image['url']));
        }
        return '';
    }

    /**
     * Get tab name by slug.
     *
     * @param string $tab_slug Tab slug.
     * @return string Tab name.
     */
    protected function get_name_tab_by_slug($tab_slug) {
        $names = [
            'newest' => esc_html__('New Arrivals', 'urna'),
            'featured' => esc_html__('Featured Products', 'urna'),
            'best_selling' => esc_html__('Best Seller', 'urna'),
            'top_rated' => esc_html__('Top Rated', 'urna'),
            'on_sale' => esc_html__('On Sale', 'urna'),
        ];

        return $names[$tab_slug] ?? esc_html__('New Arrivals', 'urna');
    }

    /**
     * Get product category ID by slug.
     *
     * @param string $slug Category slug.
     * @return int|null Category ID.
     */
    protected function get_id_cat_product_by_slug($slug) {
        $category = get_term_by('slug', $slug, 'product_cat');
        return $category ? $category->term_id : null;
    }

    /**
     * Get child categories recursively.
     *
     * @param array $categories Categories array.
     * @param int   $id_parent Parent category ID.
     * @param int   $level Recursion level.
     * @param array &$dropdown Dropdown array.
     */
    protected function get_products_category_childs($categories, $id_parent, $level, &$dropdown) {
        foreach ($categories as $key => $category) {
            if ($category->category_parent == $id_parent) {
                $dropdown[str_repeat('- ', $level) . $category->name . " ({$category->count})"] = $category->term_id;
                unset($categories[$key]);
                $this->get_products_category_childs($categories, $category->term_id, $level + 1, $dropdown);
            }
        }
    }

    /**
     * Render tab controls.
     *
     * @param string $tab_id Tab ID.
     */
    protected function render_controls_tab($tab_id) {
        $settings = $this->get_settings_for_display();
        if (empty($settings['categoriestabs'])) {
            return;
        }

        echo '<ul role="tablist" class="nav nav-tabs">';
        foreach ($settings['categoriestabs'] as $index => $tab) {
            $tab_name = !empty($tab['title']) ? $tab['title'] : $this->get_name_tab_by_slug($tab['product_type'] ?? '');
            if (!empty($tab['category']) && !empty($settings['show_catname_tabs']) && $settings['show_catname_tabs'] === 'yes') {
                $category = get_term_by('slug', $tab['category'], 'product_cat');
                $tab_name = $category ? $category->name : $tab_name;
            }

            printf(
                '<li%s><a href="#tab-%s-%d" data-toggle="tab">%s</a></li>',
                $index === 0 ? ' class="active"' : '',
                esc_attr($tab_id),
                $index,
                esc_html($tab_name)
            );
        }
        echo '</ul>';
    }

    /**
     * Render products tab layout.
     *
     * @param array $tab Tab settings.
     */
    public function render_layout_products_tab($tab) {
        $settings = $this->get_settings_for_display();
        extract(array_merge(['product_type' => '', 'category' => '', 'cat_operator' => 'IN', 'limit' => 10, 'orderby' => 'date', 'order' => 'asc', 'rows' => 1], $tab));

        $loop = urna_get_query_products($category, $cat_operator, $product_type, $limit, $orderby, $order);
        $attr_row = $this->get_render_attribute_string('row');
        $active_theme = urna_tbay_get_part_theme();

        wc_get_template("layout-products/{$active_theme}/{$settings['layout_type']}.php", [
            'loop' => $loop,
            'attr_row' => $attr_row,
            'rows' => $rows,
        ]);
    }

    /**
     * @var int Navigation menu index.
     */
    protected $nav_menu_index = 1;

    /**
     * Get unique navigation menu index.
     *
     * @return int Menu index.
     */
    protected function get_nav_menu_index() {
        return $this->nav_menu_index++;
    }

    /**
     * Render icon element.
     *
     * @param array $selected_icon Icon settings.
     */
    protected function render_item_icon($selected_icon) {
        if (empty($selected_icon['value'])) {
            return;
        }

        Icons_Manager::render_icon($selected_icon, ['aria-hidden' => 'true']);
    }

    /**
     * Register description display control for specific skin.
     */
    protected function register_display_description_skin_technology_v2() {
        if (urna_tbay_get_theme() !== 'technology-v2' || apply_filters('urna_woo_config_product_layout', 10, 2) !== 'v5') {
            return;
        }

        $this->add_control(
            'show_des',
            [
                'label' => esc_html__('Show Short Description', 'urna'),
                'description' => esc_html__('Only displayed in product style 5 on theme options', 'urna'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );
    }

    /**
     * Render menu content.
     *
     * @param string $menu_id Menu ID or slug.
     */
    protected function render_content_menu($menu_id) {
        $menus = $this->get_available_menus();
        if (empty($menus)) {
            return;
        }

        $_id = urna_tbay_random_key();
        $args = [
            'echo' => false,
            'menu' => $menu_id,
            'container_class' => 'collapse navbar-collapse',
            'menu_id' => 'menu-' . $this->get_nav_menu_index() . '-' . $_id,
            'walker' => new Urna_Tbay_Nav_Menu(),
            'fallback_cb' => '__return_empty_string',
            'container' => '',
            'menu_class' => 'elementor-nav-menu menu',
        ];

        $menu_html = wp_nav_menu($args);
        if ($menu_html) {
            $this->add_render_attribute('main-menu', 'class', ['elementor-nav-menu--main', 'elementor-nav-menu__container']);
            printf('<div class="tab-menu-wrapper"><nav %s>%s</nav></div>', $this->get_render_attribute_string('main-menu'), $menu_html);
        }
    }

    /**
     * Get SVG icon inline content.
     *
     * @param array $selected_icon Icon settings.
     * @return string SVG content.
     */
    protected function get_item_icon_svg($selected_icon) {
        return !empty($selected_icon['value']['id']) ? Svg::get_inline_svg($selected_icon['value']['id']) : '';
    }
}